@@ -3,6 +3,7 @@
 
 #include "mostQtHeaders.h"
 #include "help.h"
+#include "latexrepository.h"
 
 
 namespace Ui {
@@ -18,12 +19,15 @@ public:
 	void setPackageNames(const QStringList &packages);
 	void setPreferredPackage(const QString &package);
 
+    void setShowAllPackages(bool showAll);
+    bool showAllPackages() const;
+
 	QString selectedPackage() const;
 
 	~TexdocDialog();
 
 private slots:
-    void regenerateTable(int state=0);
+    void regenerateTable(int state=Qt::Unchecked);
     void tableSearchTermChanged(QString term);
 	void itemChanged(QTableWidgetItem* item);
 	void delayedCheckDocAvailable(const QString &package);
@@ -38,6 +42,7 @@ private:
 	QString lastDocRequest;
     Help *help;
     QStringList m_packages;
+    QButtonGroup buttonGroup;
 };
 
 #endif // TEXDOCDIALOG_H
